@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Redmine - project management software
-# Copyright (C) 2006-2022  Jean-Philippe Lang
+# Copyright (C) 2006-2023  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -837,7 +837,7 @@ class Project < ActiveRecord::Base
           if user.admin?
             true
           else
-            default_member_role.has_permission?(:select_project_modules)
+            default_member_role&.has_permission?(:select_project_modules)
           end
         else
           user.allowed_to?(:select_project_modules, project)
