@@ -1,5 +1,5 @@
 /* Redmine - project management software
-   Copyright (C) 2006-2021  Jean-Philippe Lang */
+   Copyright (C) 2006-2023  Jean-Philippe Lang */
 
 function sanitizeHTML(string) {
   var temp = document.createElement('span');
@@ -31,7 +31,7 @@ function toggleRowGroup(el) {
   var tr = $(el).parents('tr').first();
   var n = tr.next();
   tr.toggleClass('open');
-  $(el).toggleClass('icon-expended icon-collapsed');
+  $(el).toggleClass('icon-expanded icon-collapsed');
   while (n.length && !n.hasClass('group')) {
     n.toggle();
     n = n.next('tr');
@@ -43,7 +43,7 @@ function collapseAllRowGroups(el) {
   tbody.children('tr').each(function(index) {
     if ($(this).hasClass('group')) {
       $(this).removeClass('open');
-      $(this).find('.expander').switchClass('icon-expended', 'icon-collapsed');
+      $(this).find('.expander').switchClass('icon-expanded', 'icon-collapsed');
     } else {
       $(this).hide();
     }
@@ -55,7 +55,7 @@ function expandAllRowGroups(el) {
   tbody.children('tr').each(function(index) {
     if ($(this).hasClass('group')) {
       $(this).addClass('open');
-      $(this).find('.expander').switchClass('icon-collapsed', 'icon-expended');
+      $(this).find('.expander').switchClass('icon-collapsed', 'icon-expanded');
     } else {
       $(this).show();
     }
@@ -74,7 +74,7 @@ function toggleAllRowGroups(el) {
 function toggleFieldset(el) {
   var fieldset = $(el).parents('fieldset').first();
   fieldset.toggleClass('collapsed');
-  fieldset.children('legend').toggleClass('icon-expended icon-collapsed');
+  fieldset.children('legend').toggleClass('icon-expanded icon-collapsed');
   fieldset.children('div').toggle();
 }
 
@@ -550,12 +550,12 @@ function scmEntryClick(id, url) {
     var el = $('#'+id);
     if (el.hasClass('open')) {
         collapseScmEntry(id);
-        el.find('.expander').switchClass('icon-expended', 'icon-collapsed');
+        el.find('.expander').switchClass('icon-expanded', 'icon-collapsed');
         el.addClass('collapsed');
         return false;
     } else if (el.hasClass('loaded')) {
         expandScmEntry(id);
-        el.find('.expander').switchClass('icon-collapsed', 'icon-expended');
+        el.find('.expander').switchClass('icon-collapsed', 'icon-expanded');
         el.removeClass('collapsed');
         return false;
     }
@@ -568,7 +568,7 @@ function scmEntryClick(id, url) {
       success: function(data) {
         el.after(data);
         el.addClass('open').addClass('loaded').removeClass('loading');
-        el.find('.expander').switchClass('icon-collapsed', 'icon-expended');
+        el.find('.expander').switchClass('icon-collapsed', 'icon-expanded');
       }
     });
     return true;
@@ -958,7 +958,7 @@ function addFormObserversForDoubleSubmit() {
 
 function defaultFocus(){
   if (($('#content :focus').length == 0) && (window.location.hash == '')) {
-    $('#content input[type=text], #content textarea').first().focus();
+    $('#content input[type=text]:visible, #content textarea:visible').first().focus();
   }
 }
 
@@ -1127,9 +1127,13 @@ function inlineAutoComplete(element) {
     if (element.dataset.tribute === 'true') {return};
 
     const getDataSource = function(entity) {
-      const dataSources = JSON.parse(rm.AutoComplete.dataSources);
+      const dataSources = rm.AutoComplete.dataSources;
 
-      return dataSources[entity];
+      if (dataSources[entity]) {
+        return dataSources[entity];
+      } else {
+        return false;
+      }
     }
 
     const remoteSearch = function(url, cb) {
@@ -1187,6 +1191,26 @@ function inlineAutoComplete(element) {
           menuItemTemplate: function (wikiPage) {
             return sanitizeHTML(wikiPage.original.label);
           }
+        },
+        {
+          trigger: '@',
+          lookup: function (user, mentionText) {
+            return user.name + user.firstname + user.lastname + user.login;
+          },
+          values: function (text, cb) {
+            const url = getDataSource('users');
+            if (url) {
+              remoteSearch(url + text, function (users) {
+                return cb(users);
+              });
+            }
+          },
+          menuItemTemplate: function (user) {
+            return user.original.name;
+          },
+          selectTemplate: function (user) {
+            return '@' + user.original.login;
+          }
         }
       ],
       noMatchTemplate: ""
